@@ -1,5 +1,5 @@
 #include "pcre2.h"
 
-int pcre2_is_bundled() {
+int pcre2_is_bundled(void) {
   return 1;
 }
